package com.ruoyi.biz.service;

import java.util.List;
import com.ruoyi.biz.domain.BizPatentValidOg;

/**
 * 专利有效原始Service接口
 * 
 * @author dm
 * @date 2023-03-09
 */
public interface IBizPatentValidOgService 
{
    /**
     * 查询专利有效原始
     * 
     * @param id 专利有效原始主键
     * @return 专利有效原始
     */
    public BizPatentValidOg selectBizPatentValidOgById(String id);

    /**
     * 查询专利有效原始列表
     * 
     * @param bizPatentValidOg 专利有效原始
     * @return 专利有效原始集合
     */
    public List<BizPatentValidOg> selectBizPatentValidOgList(BizPatentValidOg bizPatentValidOg);

    /**
     * 新增专利有效原始
     * 
     * @param bizPatentValidOg 专利有效原始
     * @return 结果
     */
    public int insertBizPatentValidOg(BizPatentValidOg bizPatentValidOg);

    /**
     * 修改专利有效原始
     * 
     * @param bizPatentValidOg 专利有效原始
     * @return 结果
     */
    public int updateBizPatentValidOg(BizPatentValidOg bizPatentValidOg);

    /**
     * 批量删除专利有效原始
     * 
     * @param ids 需要删除的专利有效原始主键集合
     * @return 结果
     */
    public int deleteBizPatentValidOgByIds(String[] ids);

    /**
     * 删除专利有效原始信息
     * 
     * @param id 专利有效原始主键
     * @return 结果
     */
    public int deleteBizPatentValidOgById(String id);

    /**
     * 批量删除---逻辑删除
     *
     * @param ids 需要删除的专利有效原始ID
     * @return 结果
     */
    public int setDeleteByIds(String[] ids);

    /**
     * 删除---逻辑删除
     *
     * @param id 专利有效原始ID
     * @return 结果
     */
    public int setDeleteById(String id);

    /**
     * 导入专利有效原始数据
     *
     * @param bizPatentValidOgList 专利有效原始列表
     * @param operName 操作用户
     * @return 结果
     */
    public String importBizPatentValidOg(List<BizPatentValidOg> bizPatentValidOgList, String operName);
}
